@@ -5,7 +5,8 @@ See https://github.com/AnkushBhise/databaseops/ for more information
 """
 
 # Version of databaseops
-__version__ = "0.1.17"
+__version__ = "1.0.0"
 
 # Create imports from project to make every thing available at top level
-from databaseops.mysql.operations import MySQLOps
+from .mysql import MySQLOps
+from .mysql import MySQLTable
