@@ -4,4 +4,8 @@ This package created for operations on mysql database as it is dataframe
 """
 
 # Version of databaseops sub-package mysql
-__version__ = "0.1.4"
+__version__ = "1.0.0"
+
+from .mysqlops import MySQLOps
+from .mysqldatabase import MySQLDataBase
+from .mysqltable import MySQLTable
